==================================
:code:`Trakt['users/*/watchlist']`
==================================

.. automodule:: trakt.interfaces.users.watchlist

  .. autoclass:: UsersWatchlistInterface
    :members: flags, get
    :undoc-members:
